//
//	aegis - project change supervisor
//	Copyright (C) 1999, 2003-2006 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to manipulate pushba_transs
//

#include <libaegis/input.h>


void
input_ty::pushback_transfer(input &from)
{
    from->pullback_transfer(this);
}


void
input_ty::pullback_transfer(input_ty *to)
{
    if (buffer_position < buffer_end)
    {
	to->unread(buffer_position, buffer_end - buffer_position);
	buffer_position = buffer_end;
    }
}


void
input_ty::pullback_transfer(input &to)
{
    pullback_transfer(to.ref);
}
